.. _sec-data-thermoprops:

Atmosphere: Thermophysical properties
=====================================

An atmospheric thermophysical property data set provides the spatial variation
of air pressure, air temperature, air number density and air constituents'
mole fractions.

Standard atmospheric profiles, including manipulation methods, are provided
by the `Joseki <https://github.com/rayference/joseki>`_ package.

Refer to `Joseki documentation <https://rayference.github.io/joseki/latest>`_
for more details.
